==========================
YAML utilities for Tendril
==========================

.. image:: https://img.shields.io/travis/chintal/tendril-utils-yaml.svg
        :target: https://travis-ci.org/chintal/tendril-utils-yaml

.. image:: https://img.shields.io/pypi/v/tendril-utils-yaml.svg
        :target: https://pypi.python.org/pypi/tendril-utils-yaml

* License: AGPLv3
* Documentation: http://tendril-utils-yaml.readthedocs.org


YAML utilities for Tendril
